==> phpDocumentor-2.1.0.tgz: phpDocumentor-2.1.0/src/phpDocumentor/Plugin/Core/Messages/de.php <==
<?php
/**
 * phpDocumentor
 *
 * PHP Version 5.3
 *
 * @copyright 2010-2013 Mike van Riel / Naenius (http://www.naenius.com)
 * @license   http://www.opensource.org/licenses/mit-license.php MIT
 * @link      http://phpdoc.org
 */

return array(
    'PPC:ERR-50000' => 'Es wurde keine Zusammenfassung in dieser Datei gefunden',
    'PPC:ERR-50001' => 'Es ist nur ein @package Tag erlaubt',
    'PPC:ERR-50002' => 'Es ist nur ein @subpackage Tag erlaubt',
    'PPC:ERR-50004' => 'Es kann kein @subpackage vorkommen, ohne Angabe eines @package Tags',
    'PPC:ERR-50005' => 'Keine Zusammenfassung für Klasse %s',
    'PPC:ERR-50006' => 'Veraltetes Tag "%s" in %s gefunden',
    'PPC:ERR-50007' => 'Keine Zusammenfassung für Property %s',
    'PPC:ERR-50008' => 'Keine Zusammenfassung für Methode %s',
    'PPC:ERR-50009' => 'Keine Zusammenfassung für Interface %s',
    'PPC:ERR-50010' => 'Keine Zusammenfassung für Trait %s',
    'PPC:ERR-50011' => 'Keine Zusammenfassung für Funktion %s',
    'PPC:ERR-50013' => 'Parameter %s konnte nicht in %s gefunden werden',
    'PPC:ERR-50014' => 'Der Name des Arguments %s stimmt nicht mit dem Namen %s aus dem DocBlock in %s überein',
    'PPC:ERR-50015' => 'Argument %s fehlt im Docblock von %s',
    'PPC:ERR-50016' => 'Der Type-Hint von dem Argument ist für die Typ-Definition '
        . 'des @param Tags mit dem Argument %s in %s nicht korrekt',
    'PPC:ERR-50017' => 'Der Typ für das %s Tag in %s ist "type"; ist das nicht ein IDE default?',
    'PPC:ERR-50018' => 'Der Typ für das param Tag %s in %s ist entweder "type" oder "unknown"; ist das nicht ein IDE default?',
    'PPC:ERR-50020' => 'Benötigtes Tag "%s" wurde nicht in %s gefunden',
);

==> phpDocumentor-2.2.0.tgz: phpDocumentor-2.2.0/src/phpDocumentor/Plugin/Core/Messages/de.php <==
<?php
/**
 * phpDocumentor
 *
 * PHP Version 5.3
 *
 * @copyright 2010-2013 Mike van Riel / Naenius (http://www.naenius.com)
 * @license   http://www.opensource.org/licenses/mit-license.php MIT
 * @link      http://phpdoc.org
 */

/** @noinspection SpellCheckingInspection */
return array(
    'PPC:ERR-50000' => 'Es wurde keine Zusammenfassung in dieser Datei gefunden',
    'PPC:ERR-50001' => 'Es ist nur ein @package Tag erlaubt',
    'PPC:ERR-50002' => 'Es ist nur ein @subpackage Tag erlaubt',
    'PPC:ERR-50004' => 'Es kann kein @subpackage vorkommen, ohne Angabe eines @package Tags',
    'PPC:ERR-50005' => 'Keine Zusammenfassung für Klasse %s',
    'PPC:ERR-50006' => 'Veraltetes Tag "%s" in %s gefunden',
    'PPC:ERR-50007' => 'Keine Zusammenfassung für Property %s',
    'PPC:ERR-50008' => 'Keine Zusammenfassung für Methode %s',
    'PPC:ERR-50009' => 'Keine Zusammenfassung für Interface %s',
    'PPC:ERR-50010' => 'Keine Zusammenfassung für Trait %s',
    'PPC:ERR-50011' => 'Keine Zusammenfassung für Funktion %s',
    'PPC:ERR-50013' => 'Parameter %s konnte nicht in %s gefunden werden',
    'PPC:ERR-50014' => 'Der Name des Arguments %s stimmt nicht mit dem Namen %s aus dem DocBlock in %s überein',
    'PPC:ERR-50015' => 'Argument %s fehlt im Docblock von %s',
    'PPC:ERR-50016' => 'Der Type-Hint von dem Argument ist für die Typ-Definition '
        . 'des @param Tags mit dem Argument %s in %s nicht korrekt',
    'PPC:ERR-50017' => 'Der Typ für das %s Tag in %s ist "type"; ist das nicht ein IDE default?',
    'PPC:ERR-50018' => 'Der Typ für das param Tag %s in %s ist entweder "type" oder "unknown"; ist das nicht ein '
        . 'IDE default?',
    'PPC:ERR-50020' => 'Benötigtes Tag "%s" wurde nicht in %s gefunden',
);
